from bruhanimate.bruhscreen import Screen
from bruhanimate.bruhrenderer import CenterRenderer
import bruhanimate.images as images

import os
os.system(" ")

def snow(screen):
    try:
        renderer = CenterRenderer(
            screen=screen,
            img=images.text_to_image("SNOW!"),
            frames=float("inf"),
            time=0.075,
            effect_type="snow",
            background=" ",
            transparent=True
        )
        
        renderer.update_collision(True)

        renderer.update_smart_transparent(True)

        renderer.run()

        input()

    except KeyboardInterrupt:
        renderer.render_exit()
        renderer.push_front_to_screen()
        input()


def run():
    Screen.show(snow)


if __name__ == "__main__":
    run()



from bruhanimate.bruhscreen import Screen
from bruhanimate.bruhrenderer import CenterRenderer
import bruhanimate.images as images

import os

os.system(" ")


def gol(screen):
    try:
        renderer = CenterRenderer(
            screen=screen,
            frames=float("inf"),
            img=images.text_to_image("GOL!"),
            time=0.0,
            effect_type="gol",
            background=" ",
            transparent=False,
        )

        renderer.effect.update_decay(True, "RAINBOW", "default")

        renderer.run()

        input()

    except KeyboardInterrupt:
        renderer.render_exit()
        renderer.push_front_to_screen()
        input()


def run():
    Screen.show(gol)


if __name__ == "__main__":
    run()


from bruhanimate.bruhrenderer import *
from bruhanimate.bruhscreen import Screen
import bruhanimate.images as images


def demo(screen, img, frames, time, effect, background, transparent):
    try:
        # CREATE THE RENDERER
        renderer = PanRenderer(
            screen=screen,
            frames=frames,
            time=time,
            img=img,
            effect_type=effect,
            background=background,
            transparent=transparent,
            loop=True,
        )

        # REGISTER THE LINES - LET'S MAKE A DECENT 3D TRIANGLE
        renderer.effect.add_line((15, 15), (30, 30))
        renderer.effect.add_line((30, 30), (50, 20))
        renderer.effect.add_line((50, 20), (15, 15))

        renderer.effect.add_line((30, 30), (32, 22))
        renderer.effect.add_line((32, 22), (15, 15))
        renderer.effect.add_line((32, 22), (50, 20))

        # RUN THE ANIMATION
        renderer.run(end_message=False)

        # CATCH THE END WITH INPUT() ON WINDOWS
        input()
    except KeyboardInterrupt:
        renderer.render_exit()
        renderer.push_front_to_screen()
        input()


def run():
    image = images.text_to_image(
        "HELLO WORLD!", padding_top_bottom=1, padding_left_right=3
    )
    Screen.show(demo, args=(image, 500, 0.05, "drawlines", " ", True))


if __name__ == "__main__":
    run()



from bruhanimate.bruhrenderer import *
from bruhanimate.bruhscreen import Screen
import bruhanimate.images as images


def show(screen):
    try:
        image = images.text_to_image(
            "PLASMA!", padding_top_bottom=1, padding_left_right=3
        )

        # Create the renderer
        renderer = FocusRenderer(
            screen=screen,
            frames=500,
            time=0,
            img=image,
            effect_type="plasma",
            background=" ",
            transparent=False,
            start_frame=110,
            reverse=True,
            start_reverse=300,
        )

        # Set the attributes
        renderer.effect.update_color_properties(
            color=True, characters=True, random_color=True
        )

        renderer.effect.update_grey_scale_size(10)

        renderer.effect.update_plasma_values(10, 26, 19, 41)
        
        renderer.effect.update_info_visibility(True)

        # Run the animation
        renderer.update_exit_stats(
            "   Hey dude, the frames are done!   ",
            "        Press [Enter] to exit       ",
            wipe=True,
            centered=True,
        )
        renderer.run(end_message=True)

        # Catch the end with input() --> for Win-Systems --> no input() is needed for Unix-Systems
        input()

    except KeyboardInterrupt:
        renderer.render_exit()
        renderer.push_front_to_screen()
        input()


def run():
    Screen.show(show)


if __name__ == "__main__":
    run()



"""
Copyright 2023 Ethan Christensen

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import re
import random
import pyfiglet
import bruhcolor

BRUH = [
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
    r"loading BRUH         _             _           oading BRUH ",
    r"loading BRUH       /\ \          / /\          oading BRUH ",
    r"loading BRUH      /  \ \        / /  \         oading BRUH ",
    r"loading BRUH     / /\ \ \      / / /\ \        oading BRUH ",
    r"loading BRUH     \/_/\ \ \    / / /\ \ \       oading BRUH ",
    r"loading BRUH         / / /   /_/ /  \ \ \      oading BRUH ",
    r"loading BRUH        / / /    \ \ \   \ \ \     oading BRUH ",
    r"loading BRUH       / / /  _   \ \ \   \ \ \    oading BRUH ",
    r"loading BRUH      / / /_/\_\ _ \ \ \___\ \ \   oading BRUH ",
    r"loading BRUH     / /_____/ //\_\\ \/____\ \ \  oading BRUH ",
    r"loading BRUH     \________/ \/_/ \_________\/  oading BRUH ",
    r"loading BRUH                                   oading BRUH ",
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
    r"loading BRUH SHELL 2.0 loading BRUH SHELL 2.0 loading BRUH ",
]

BRUH_EMPTY = [
    r"    _             _          ",
    r"  /\ \          / /\         ",
    r" /  \ \        / /  \        ",
    r"/ /\ \ \      / / /\ \       ",
    r"\/_/\ \ \    / / /\ \ \      ",
    r"    / / /   /_/ /  \ \ \     ",
    r"   / / /    \ \ \   \ \ \    ",
    r"  / / /  _   \ \ \   \ \ \   ",
    r" / / /_/\_\ _ \ \ \___\ \ \  ",
    r"/ /_____/ //\_\\ \/____\ \ \ ",
    r"\________/ \/_/ \_________\/ ",
]

COMPUTER = [
    f"                       .,,uod8B8bou,,.                             ",
    f"              ..,uod8BBBBBBBBBBBBBBBBRPFT?l!i:.                    ",
    f"         ,=m8BBBBBBBBBBBBBBBRPFT?!||||||||||||||                   ",
    f'         !...:!TVBBBRPFT||||||||||!!^^""\'    |||                   ',
    f'         !.......:!?|||||!!^^""\'             |||                   ',
    f"         !.........|||   ___ ___ _   _ _  _  |||                   ",
    f"         !.........|||  | _ ) _ \ | | | || | |||                   ",
    f"         !.........|||  | _ \   / |_| | __ | |||                   ",
    f"         !.........|||  |___/_|_\\\___/|_||_| |||                   ",
    f"         !.........|||   ---   --            |||                   ",
    f"         !.........|||  |_  ) /  \           |||                   ",
    f"         `.........|||   / / | () |        , |||                   ",
    f"          .;.......|||  /___(_)__/     _.-!!||||                   ",
    f"   .,uodWBBBBb.....|||        _.-!!|||||||||!:'                    ",
    f"!YBBBBBBBBBBBBBBb..!|||:..-!!|||||||!iof68BBBBBb....               ",
    f"!..YBBBBBBBBBBBBBBb!!||||||||!iof68BBBBBBRPFT?!::   `.             ",
    f"!....YBBBBBBBBBBBBBBbaaitf68BBBBBBRPFT?!:::::::::     `.           ",
    f'!......YBBBBBBBBBBBBBBBBBBBRPFT?!::::::;:!^"`;:::       `.         ',
    f"!........YBBBBBBBBBBRPFT?!::::::::::^''...::::::;         iBBbo.   ",
    f"`..........YBRPFT?!::::::::::::::::::::::::;iof68bo.      WBBBBbo. ",
    f"  `..........:::::::::::::::::::::::;iof688888888888b.     `YBBBP^'",
    f"    `........::::::::::::::::;iof688888888888888888888b.     `     ",
    f"      `......:::::::::;iof688888888888888888888888888888b.         ",
    f"        `....:::;iof688888888888888888888888888888888899fT!        ",
    f"          `..::!8888888888888888888888888888888899fT|!^\"'          ",
    f"            `' !!988888888888888888888888899fT|!^\"'                ",
    f"                `!!8888888888888888899fT|!^\"'                      ",
    f"                  `!988888888899fT|!^\"'                            ",
    f"                    `!9899fT|!^\"'                                  ",
    f"                      `!^\"'                                        ",
]

HEY = [
    f"    __  __          ",
    f"   / / / /__  __  __",
    f"  / /_/ / _ \/ / / /",
    f" / __  /  __/ /_/ / ",
    f"/_/ /_/\___/\__, /  ",
    f"           /____/   ",
]

TWOPOINT = [
    r"                                                                               ",
    r"   ____________ _   _ _   _  _____ _   _  _____ _      _       _____  _____    ",
    r"   | ___ \ ___ \ | | | | | |/  ___| | | ||  ___| |    | |     / __  \|  _  |   ",
    r"   | |_/ / |_/ / | | | |_| |\ `--.| |_| || |__ | |    | |     `' / /'| |/' |   ",
    r"   | ___ \    /| | | |  _  | `--. \  _  ||  __|| |    | |       / /  |  /| |   ",
    r"   | |_/ / |\ \| |_| | | | |/\__/ / | | || |___| |____| |____ ./ /___\ |_/ /   ",
    r"   \____/\_| \_|\___/\_| |_/\____/\_| |_/\____/\_____/\_____/ \_____(_)___/    ",
    r"                                                                               ",
]

CHRISTMAS_1 = [
    r"                ",
    r"      _\/_      ",
    r"       /\       ",
    r"       /\       ",
    r"      /  \      ",
    r"      /~~\ o    ",
    r"     / o  \     ",
    r"    /~~*~~~\    ",
    r"  o /    o \    ",
    r"   /~~~~~~~~\~` ",
    r"  /__*_______\  ",
    r"       ||       ",
    r"     \====/     ",
    r"      \__/      ",
    r"                ",
]


_REGISTERED_IMAGES = {
    "BRUH": BRUH,
    "BRUH_EMPTY": BRUH_EMPTY,
    "COMPUTER": COMPUTER,
    "HEY": HEY,
    "TWOPOINT": TWOPOINT,
    "CHRISTMAS_1": CHRISTMAS_1,
}


def get_image(name):
    """
    Function to return one of the premade images
    :param name: name of the image to get
    """
    if name in _REGISTERED_IMAGES:
        return _REGISTERED_IMAGES[name]
    else:
        return _REGISTERED_IMAGES["HEY"]


def text_to_image(
    text, font=pyfiglet.DEFAULT_FONT, padding_top_bottom=0, padding_left_right=0
):
    """
    Function to take a piece of text and turn it into
    an image that can be used.
    :param text: text to turn into an image
    :param font: pyfiglet font to use
    :param padding_top_bottom: padding to apply to the generated image
    :param padding_left_right: padding to apply to the generate image
    """
    
    img_flat = None
    try:
        img_flat = pyfiglet.Figlet(font).renderText(text)
    except:
        img_flat = pyfiglet.Figlet().renderText("Invalid Font")
    img = []
    row = ""
    for val in img_flat:
        if val == "\n":
            img.append(row)
            row = ""
        else:
            row += val

    if padding_top_bottom > 0:
        img = (
            [" " * len(img[0]) for __ in range(padding_top_bottom)]
            + img
            + [" " * len(img[0]) for __ in range(padding_top_bottom)]
        )
    if padding_left_right > 0:
        for i in range(len(img)):
            img[i] = (" " * padding_left_right) + img[i] + (" " * padding_left_right)
    return img
